<?php

/*! \class CMantisImportUserLDAP 
    \brief Cette classe  pour rle de grer les transactions avec le service LDAP.
*/
class CMantisImportUserLDAP
{
    private $szLdap_Server;    /*!< Chaine de caractres contenant l'adresse du serveur LDAP.*/
    private $iLdap_Port;       /*!< Entier contenant le port du service LDAP.*/ 
    private $szLdap_Bind_Dn;   /*!< Chaine de caractres contenant l'identifiant avec lequel on s'authentifie auprs du service LDAP.*/
    private $szLdap_Pwd;       /*!< Chaine de caractres contenant le mot de passe pour se connecter au service LDAP.*/
    private $szLdap_Dn;        /*!< Chaine de caractres contenant un chemin valide de l'annuaire LDAP.*/
    private $szLdap_Filter;    /*!< Chaine de caractres contenant le filtre li  la recherche LDAP.*/
    private $szLdap_Select;    /*!< Chaine de caractres contenant la slection des lments devant-tre  retourne par la recherche LDAP.*/ 
    
    private $ldapconn;         /*!< Objet de connexion LDAP.*/
    private $aResultOfSearch;  /*!< Tableau contenant le rsultat de la recherche.*/
    
    /*! \fn __construct($aServer_Parameters,$aSearch_Parameters)
        \brief Constructeur : nous permet d'initaliser nos diffrents attributs.
        \param $aServer_Parameters Tableau de chaines de caractres contenant les paramtres serveurs (adresse du serveur, port, bind dn, mot de passe).
        \param $aSearch_Parameters Tableau de chaines de caractres contenant les paramtres de recherche (dn, filtre).
    */
    public function __construct($aServer_Parameters,$aSearch_Parameters)
    {
        if(isset($aServer_Parameters) && isset($aSearch_Parameters))
        {
             $this->szLdap_Server  = $aServer_Parameters[0];
             $this->iLdap_Port     = $aServer_Parameters[1];
             $this->szLdap_Bind_Dn = $aServer_Parameters[2];
             $this->szLdap_Pwd     = $aServer_Parameters[3];
             
             $this->szLdap_Dn      = $aSearch_Parameters[0];
             $this->szLdap_Filter  = $aSearch_Parameters[1];
              
             $this->szLdap_Select   = MANTIS_IMPORTUSER_LANG_DFT_SELECT;
             $this->ldapconn        = null;
             $this->aResultOfSearch = array();
             
             if(!(isset($this->szLdap_Server) && isset($this->iLdap_Port) && isset($this->szLdap_Bind_Dn) && isset($this->szLdap_Dn) && isset($this->szLdap_Filter)))
             {
                 trigger_error( ERROR_MANTISIMPORTUSER_CONSTRUCTOR_PARAMETERS_NULL, ERROR );
             }
        }
        else
        {
            trigger_error( ERROR_MANTISIMPORTUSER_CONSTRUCTOR_PARAMETERS_NULL, ERROR ); 
        }
    }
    
    /*! \fn ConnectToServer()
        \brief Mthode permettant d'ouvrir une connexion LDAP.
    */
    public function ConnectToServer()
    {
        if(!($this->ldapconn = ldap_connect( $this->szLdap_Server, $this->iLdap_Port ))) 
        {
            trigger_error( ERROR_MANTISIMPORTUSER_CONNECT_SERVER, ERROR ); 
        }
        
        if(!(ldap_bind($this->ldapconn, $this->szLdap_Bind_Dn, $this->szLdap_Pwd)))
        {
            trigger_error( ERROR_MANTISIMPORTUSER_IDENTIFICATION_SERVER, ERROR );
        } 
    }
    
    /*! \fn CloseConnexionToServer()
        \brief Mthode permettant de fermer une connexion LDAP.
    */
    public function CloseConnexionToServer()
    {
        if(!(ldap_unbind($this->ldapconn)))
        {
            trigger_error( ERROR_MANTISIMPORTUSER_CLOSE_LDAP_CONNEXION, ERROR ); 
        }
    }
    
    /*! \fn RunSearch($szLdap_Select=array('cn','sn'))
        \brief Mthode permettant de lancer la recherche.
        \param $szLdap_Select Chaine de caractres contenant la slection des lments devant-tre  retourne par la recherche LDAP.
    */
    public function RunSearch($szLdap_Select=array('cn','sn'))
    {
        $this->szLdap_Select = $szLdap_Select;
        $sr=ldap_search($this->ldapconn, $this->szLdap_Dn, $this->szLdap_Filter, $this->szLdap_Select);
        if($sr)
        {
            $this->aResultOfSearch = ldap_get_entries($this->ldapconn, $sr);          
            if(!($this->aResultOfSearch))
            {
                trigger_error( ERROR_MANTISIMPORTUSER_RUN_LDAP_GET_ENTRIES, ERROR );     
            }
        }
        else
        {
            trigger_error( ERROR_SEARCH_USERS, ERROR );
        }
        return($this->aResultOfSearch);
    }
    
    /*! \fn getaResultOfSearch()
        \brief Mthode d'accs permettant de retourner le rsultat de la recherche au format d'un tableau.
        \return $this->aResultOfSearch Tableau contenant le rsultat de la recherche LDAP.
    */
    public function getaResultOfSearch()
    {
        if(!(isset($this->aResultOfSearch)))
        {
           $this->aResultOfSearch = array(); 
        }
        return($this->aResultOfSearch);
    }
}

?>
